Enum cw721::Cw721ExecuteMsg
source · [−]pub enum Cw721ExecuteMsg {
TransferNft {
recipient: String,
token_id: String,
},
SendNft {
contract: String,
token_id: String,
msg: Binary,
},
Approve {
spender: String,
token_id: String,
expires: Option<Expiration>,
},
Revoke {
spender: String,
token_id: String,
},
ApproveAll {
operator: String,
expires: Option<Expiration>,
},
RevokeAll {
operator: String,
},
}Variants
TransferNft
Transfer is a base message to move a token to another account without triggering actions
SendNft
Send is a base message to transfer a token to a contract and trigger an action on the receiving contract.
Approve
Allows operator to transfer / send the token from the owner’s account. If expiration is set, then this allowance has a time/height limit
Revoke
Remove previously granted Approval
ApproveAll
Allows operator to transfer / send any token from the owner’s account. If expiration is set, then this allowance has a time/height limit
RevokeAll
Fields
operator: StringRemove previously granted ApproveAll permission