pub struct Cw721InstantiateMsg<TCollectionExtensionMsg> {
pub name: String,
pub symbol: String,
pub collection_info_extension: TCollectionExtensionMsg,
pub minter: Option<String>,
pub creator: Option<String>,
pub withdraw_address: Option<String>,
}Fields
name: StringName of the NFT contract
symbol: StringSymbol of the NFT contract
collection_info_extension: TCollectionExtensionMsgOptional extension of the collection metadata
minter: Option<String>The minter is the only one who can create new NFTs. This is designed for a base NFT that is controlled by an external program or contract. You will likely replace this with custom logic in custom NFTs
creator: Option<String>Sets the creator of collection. The creator is the only one eligible to update CollectionInfo.
withdraw_address: Option<String>Trait Implementations
Sourceimpl<TCollectionExtensionMsg: Clone> Clone for Cw721InstantiateMsg<TCollectionExtensionMsg>
impl<TCollectionExtensionMsg: Clone> Clone for Cw721InstantiateMsg<TCollectionExtensionMsg>
Sourcefn clone(&self) -> Cw721InstantiateMsg<TCollectionExtensionMsg>
fn clone(&self) -> Cw721InstantiateMsg<TCollectionExtensionMsg>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<TCollectionExtensionMsg: Debug> Debug for Cw721InstantiateMsg<TCollectionExtensionMsg>
impl<TCollectionExtensionMsg: Debug> Debug for Cw721InstantiateMsg<TCollectionExtensionMsg>
Sourceimpl<'de, TCollectionExtensionMsg> Deserialize<'de> for Cw721InstantiateMsg<TCollectionExtensionMsg>where
TCollectionExtensionMsg: Deserialize<'de>,
impl<'de, TCollectionExtensionMsg> Deserialize<'de> for Cw721InstantiateMsg<TCollectionExtensionMsg>where
TCollectionExtensionMsg: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<TCollectionExtensionMsg: JsonSchema> JsonSchema for Cw721InstantiateMsg<TCollectionExtensionMsg>
impl<TCollectionExtensionMsg: JsonSchema> JsonSchema for Cw721InstantiateMsg<TCollectionExtensionMsg>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<TCollectionExtensionMsg: PartialEq> PartialEq for Cw721InstantiateMsg<TCollectionExtensionMsg>
impl<TCollectionExtensionMsg: PartialEq> PartialEq for Cw721InstantiateMsg<TCollectionExtensionMsg>
Sourcefn eq(&self, other: &Cw721InstantiateMsg<TCollectionExtensionMsg>) -> bool
fn eq(&self, other: &Cw721InstantiateMsg<TCollectionExtensionMsg>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<TCollectionExtensionMsg> Serialize for Cw721InstantiateMsg<TCollectionExtensionMsg>where
TCollectionExtensionMsg: Serialize,
impl<TCollectionExtensionMsg> Serialize for Cw721InstantiateMsg<TCollectionExtensionMsg>where
TCollectionExtensionMsg: Serialize,
impl<TCollectionExtensionMsg> StructuralPartialEq for Cw721InstantiateMsg<TCollectionExtensionMsg>