pub struct RoyaltyInfo {
pub payment_address: Addr,
pub share: Decimal,
}Fields
payment_address: AddrTrait Implementations
Sourceimpl Clone for RoyaltyInfo
impl Clone for RoyaltyInfo
Sourcefn clone(&self) -> RoyaltyInfo
fn clone(&self) -> RoyaltyInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Cw721CustomMsg for RoyaltyInfo
impl Cw721State for RoyaltyInfo
Sourceimpl Debug for RoyaltyInfo
impl Debug for RoyaltyInfo
Sourceimpl<'de> Deserialize<'de> for RoyaltyInfo
impl<'de> Deserialize<'de> for RoyaltyInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RoyaltyInfo> for RoyaltyInfoResponse
impl From<RoyaltyInfo> for RoyaltyInfoResponse
Sourcefn from(royalty_info: RoyaltyInfo) -> Self
fn from(royalty_info: RoyaltyInfo) -> Self
Converts to this type from the input type.
Sourceimpl FromAttributesState for RoyaltyInfo
impl FromAttributesState for RoyaltyInfo
fn from_attributes_state( attributes: &[Attribute], ) -> Result<Self, Cw721ContractError>
Sourceimpl JsonSchema for RoyaltyInfo
impl JsonSchema for RoyaltyInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RoyaltyInfo
impl PartialEq for RoyaltyInfo
Sourcefn eq(&self, other: &RoyaltyInfo) -> bool
fn eq(&self, other: &RoyaltyInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RoyaltyInfo
impl Serialize for RoyaltyInfo
Sourceimpl StateFactory<RoyaltyInfo> for RoyaltyInfoResponse
impl StateFactory<RoyaltyInfo> for RoyaltyInfoResponse
fn create( &self, deps: Deps<'_>, env: &Env, info: Option<&MessageInfo>, current: Option<&RoyaltyInfo>, ) -> Result<RoyaltyInfo, Cw721ContractError>
fn validate( &self, deps: Deps<'_>, _env: &Env, _info: Option<&MessageInfo>, current: Option<&RoyaltyInfo>, ) -> Result<(), Cw721ContractError>
impl StructuralPartialEq for RoyaltyInfo
Sourceimpl ToAttributesState for RoyaltyInfo
impl ToAttributesState for RoyaltyInfo
fn to_attributes_state(&self) -> Result<Vec<Attribute>, Cw721ContractError>